@@ -1,5 +1,4 @@
-import Class2
-
+from my_python_utility import Class2
 
 class Class1:
     def __init__(self, name, age):
